@@ -45,7 +45,7 @@ class ER(
 
     .. math::
 
-        y_k= F^\ell[y_{k-1}, \dotsc, y_{k-n_y},x_{k-d}, x_{k-d-1}, \dotsc, x_{k-d-n_x} + e_{k-1}, \dotsc, e_{k-n_e}] + e_k
+        y_k= F^\ell[y_{k-1}, \dotsc, y_{k-n_y},x_{k-d}, x_{k-d-1}, \dotsc, x_{k-d-n_x}, e_{k-1}, \dotsc, e_{k-n_e}] + e_k
 
     where :math:`n_y\in \mathbb{N}^*`, :math:`n_x \in \mathbb{N}`, :math:`n_e \in \mathbb{N}`,
     are the maximum lags for the system output and input respectively;
@@ -141,6 +141,7 @@ class ER(
         Estimating mutual information. Physical Review E, 69:066-138,2004
     .. [4] Alexander Kraskov, Harald St¨ogbauer, and Peter Grassberger.
         Estimating mutual information. Physical Review E, 69:066-138,2004
+
     """
 
     def __init__(
@@ -239,6 +240,7 @@ class ER(
 
     def mutual_information_knn(self, y, y_perm):
         """Finds the mutual information.
+
         Finds the mutual information between :math:`x` and :math:`y` given :math:`z`.
 
         This code is based on Matlab Entropic Regression package.
@@ -266,6 +268,7 @@ class ER(
             Estimating mutual information. Physical Review E, 69:066-138,2004
         .. [4] Alexander Kraskov, Harald St¨ogbauer, and Peter Grassberger.
             Estimating mutual information. Physical Review E, 69:066-138,2004
+
         """
         joint_space = np.concatenate([y, y_perm], axis=1)
         smallest_distance = np.sort(
@@ -452,7 +455,7 @@ class ER(
         smallest_distance = smallest_distance[:, idx]
         epsilon = smallest_distance[:, -1].reshape(-1, 1)
         # Find number of points from (y,f2), (f1,f2), and (f2,f2) that lies withing the
-        # k^{th} nearest neighbor distance from each point of themself.
+        # k^{th} nearest neighbor distance from each point of themselves.
         smallest_distance_y_f2 = cdist(
             np.concatenate([y, f2], axis=1),
             np.concatenate([y, f2], axis=1),
@@ -556,6 +559,7 @@ class ER(
             Estimating mutual information. Physical Review E, 69:066-138,2004
         .. [4] Alexander Kraskov, Harald St¨ogbauer, and Peter Grassberger.
             Estimating mutual information. Physical Review E, 69:066-138,2004
+
         """
         if y is None:
             raise ValueError("y cannot be None")
