@@ -11,6 +11,7 @@
 import warnings
 
 import numpy as np
+
 from sysidentpy.utils._check_arrays import _check_positive_int, _num_features, check_X_y
 
 from ..narmax_base import (
@@ -38,7 +39,7 @@ class FROLS(
 
     .. math::
 
-        y_k= F^\ell[y_{k-1}, \dotsc, y_{k-n_y},x_{k-d}, x_{k-d-1}, \dotsc, x_{k-d-n_x} + e_{k-1}, \dotsc, e_{k-n_e}] + e_k
+        y_k= F^\ell[y_{k-1}, \dotsc, y_{k-n_y},x_{k-d}, x_{k-d-1}, \dotsc, x_{k-d-n_x}, e_{k-1}, \dotsc, e_{k-n_e}] + e_k
 
     where :math:`n_y\in \mathbb{N}^*`, :math:`n_x \in \mathbb{N}`, :math:`n_e \in \mathbb{N}`,
     are the maximum lags for the system output and input respectively;
@@ -74,10 +75,6 @@ class FROLS(
         Whether to use extended least squares method
         for parameter estimation.
         Note that we define a specific set of noise regressors.
-    aux_lag : int, default=1
-        Temporary lag value used only for parameter estimation.
-        This value is overwritten by the max_lag value and will
-        be removed in v0.1.4.
     lam : float, default=0.98
         Forgetting factor of the Recursive Least Squares method.
     delta : float, default=0.01
@@ -145,6 +142,7 @@ class FROLS(
     .. [2] Manuscript (portuguese): Identificação de Sistemas não Lineares
        Utilizando Modelos NARMAX Polinomiais – Uma Revisão
        e Novos Resultados
+
     """
 
     def __init__(
@@ -325,7 +323,7 @@ class FROLS(
         ----------
         y : array-like of shape = n_samples
             Target values of the system.
-        X : array-like of shape = n_samples
+        X_base : array-like of shape = n_samples
             Input system values measured by the user.
 
         Returns
@@ -335,9 +333,6 @@ class FROLS(
             for models with N terms (where N is the
             vector position + 1).
 
-        References
-        ----------
-
         """
         if self.n_info_values is not None and self.n_info_values > X_base.shape[1]:
             self.n_info_values = X_base.shape[1]
