@@ -25,7 +25,7 @@ class MetaMSS(SimulateNARMAX, BPSOGSA):
 
     .. math::
 
-        y_k= F^\ell[y_{k-1}, \dotsc, y_{k-n_y},x_{k-d}, x_{k-d-1}, \dotsc, x_{k-d-n_x} + e_{k-1}, \dotsc, e_{k-n_e}] + e_k
+        y_k= F^\ell[y_{k-1}, \dotsc, y_{k-n_y},x_{k-d}, x_{k-d-1}, \dotsc, x_{k-d-n_x}, e_{k-1}, \dotsc, e_{k-n_e}] + e_k
 
     where :math:`n_y\in \mathbb{N}^*`, :math:`n_x \in \mathbb{N}`, :math:`n_e \in \mathbb{N}`,
     are the maximum lags for the system output and input respectively;
@@ -85,9 +85,6 @@ class MetaMSS(SimulateNARMAX, BPSOGSA):
         values.
     n_agents : int, default=10
         The number of agents to search the optimal solution.
-    dimension : int, default=15
-        The dimension of the search space.
-        criteria method.
     p_zeros : float, default=0.5
         The probability of getting ones in the construction of the population.
     p_zeros : float, default=0.5
@@ -148,6 +145,7 @@ class MetaMSS(SimulateNARMAX, BPSOGSA):
        DOI: 10.17648/sbai-2019-111317
     .. [3] Master thesis: Meta model structure selection: an algorithm for
        building polynomial NARX models for regression and classification
+
     """
 
     def __init__(
@@ -252,6 +250,7 @@ class MetaMSS(SimulateNARMAX, BPSOGSA):
         Returns
         -------
         self : returns an instance of self.
+
         """
         if self.basis_function.__class__.__name__ != "Polynomial":
             raise NotImplementedError(
@@ -431,7 +430,6 @@ class MetaMSS(SimulateNARMAX, BPSOGSA):
                 the values of the p_value of each regressor of the model
 
         """
-
         sum_of_squared_residues = np.sum(residues**2)
         variance_of_residues = (sum_of_squared_residues) / (
             len(residues) - psi.shape[1]
@@ -473,6 +471,7 @@ class MetaMSS(SimulateNARMAX, BPSOGSA):
         -------
         aic : float
             The Akaike Information Criterion
+
         """
         mse = mean_squared_error(y_test, yhat)
         n = y_test.shape[0]
@@ -494,6 +493,7 @@ class MetaMSS(SimulateNARMAX, BPSOGSA):
         -------
         bic : float
             The Bayesian Information Criterion
+
         """
         mse = mean_squared_error(y_test, yhat)
         n = y_test.shape[0]
@@ -508,13 +508,14 @@ class MetaMSS(SimulateNARMAX, BPSOGSA):
             The output data (initial conditions) to be used in the prediction process.
         yhat : ndarray of floats
             The n-steps-ahead predicted values of the model.
-        n_theta : ndarray of floats
+        n_terms : ndarray of floats
             The number of model parameters.
 
         Returns
         -------
         metamss_loss : float
             The MetaMSS loss function
+
         """
         penalty_count = np.arange(0, self.dimension)
         penalty_distribution = (np.log(n_terms + 1) ** (-1)) / self.dimension
@@ -549,6 +550,7 @@ class MetaMSS(SimulateNARMAX, BPSOGSA):
         -------
         penalty : ndarray of floats
             The values of the penalty function
+
         """
         return (
             1
@@ -570,9 +572,9 @@ class MetaMSS(SimulateNARMAX, BPSOGSA):
 
         Parameters
         ----------
-        X : ndarray of floats
+        X_test : ndarray of floats
             The input data to be used in the prediction process.
-        y : ndarray of floats
+        y_test : ndarray of floats
             The output data to be used in the prediction process.
         steps_ahead : int (default = None)
             The user can use free run simulation, one-step ahead prediction
