@@ -87,7 +87,7 @@ class Estimators(InformationMatrix):
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
@@ -100,7 +100,7 @@ class Estimators(InformationMatrix):
         .. [1] Manuscript: Sorenson, H. W. (1970). Least-squares estimation:
            from Gauss to Kalman. IEEE spectrum, 7(7), 63-68.
            http://pzs.dstu.dp.ua/DataMining/mls/bibl/Gauss2Kalman.pdf
-        .. [2] Book (Portuguese): Aguirre, L. A. (2007). Introduçaoa identificação
+        .. [2] Book (Portuguese): Aguirre, L. A. (2007). Introdução identificação
            de sistemas: técnicas lineares e não-lineares aplicadas a sistemas
            reais. Editora da UFMG. 3a edição.
         .. [3] Manuscript: Markovsky, I., & Van Huffel, S. (2007).
@@ -114,7 +114,6 @@ class Estimators(InformationMatrix):
         self._check_linear_dependence_rows(psi)
 
         y = y[self.max_lag :, 0].reshape(-1, 1)
-        # theta = np.dot(np.linalg.pinv(np.dot(psi.T, psi)), np.dot(psi.T, y))
         theta = np.linalg.lstsq(psi, y, rcond=None)[0]
         return theta
 
@@ -127,7 +126,7 @@ class Estimators(InformationMatrix):
             The information matrix of the model.
         X : ndarray of floats
             The input data to be used in the training process.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
         biased_theta : array-like of shape = number_of_model_elements
             The estimated biased parameters of the model.
@@ -178,7 +177,7 @@ class Estimators(InformationMatrix):
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
@@ -217,12 +216,12 @@ class Estimators(InformationMatrix):
     def recursive_least_squares(self, psi, y):
         """Estimate the model parameters using the Recursive Least Squares method.
 
-        The implementation consider the forgeting factor.
+        The implementation consider the forgetting factor.
         Parameters
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
@@ -238,7 +237,7 @@ class Estimators(InformationMatrix):
 
         References
         ----------
-        .. [1] Book (Portuguese): Aguirre, L. A. (2007). Introduçaoa identificação
+        .. [1] Book (Portuguese): Aguirre, L. A. (2007). Introdução identificação
            de sistemas: técnicas lineares e não-lineares aplicadas a sistemas
            reais. Editora da UFMG. 3a edição.
 
@@ -274,7 +273,7 @@ class Estimators(InformationMatrix):
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
@@ -316,7 +315,7 @@ class Estimators(InformationMatrix):
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
@@ -362,7 +361,7 @@ class Estimators(InformationMatrix):
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
@@ -409,7 +408,7 @@ class Estimators(InformationMatrix):
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
@@ -460,7 +459,7 @@ class Estimators(InformationMatrix):
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
@@ -510,7 +509,7 @@ class Estimators(InformationMatrix):
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
@@ -558,7 +557,7 @@ class Estimators(InformationMatrix):
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
@@ -608,7 +607,7 @@ class Estimators(InformationMatrix):
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
@@ -657,7 +656,7 @@ class Estimators(InformationMatrix):
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
@@ -707,7 +706,7 @@ class Estimators(InformationMatrix):
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
@@ -757,7 +756,7 @@ class Estimators(InformationMatrix):
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
@@ -804,7 +803,7 @@ class Estimators(InformationMatrix):
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
@@ -860,7 +859,7 @@ class Estimators(InformationMatrix):
         ----------
         psi : ndarray of floats
             The information matrix of the model.
-        y_train : array-like of shape = y_training
+        y : array-like of shape = y_training
             The data used to training the model.
 
         Returns
