@@ -1,4 +1,5 @@
-from sysidentpy.polynomial_basis import PolynomialNarmax
+from sysidentpy.model_structure_selection import FROLS
+from sysidentpy.basis_function._basis_function import Polynomial
 
 import numpy as np
 from numpy.testing import assert_almost_equal, assert_raises
@@ -28,37 +29,37 @@ def create_test_data(n=1000):
 
 def test_least_squares():
     x, y, theta = create_test_data()
-    model = PolynomialNarmax(
-        non_degree=2,
+    basis_function = Polynomial(degree=2)
+    model = FROLS(
         n_terms=5,
         extended_least_squares=False,
         ylag=[1, 2],
         xlag=2,
         estimator="least_squares",
+        basis_function=basis_function,
     )
-    model.fit(x, y)
+    model.fit(X=x, y=y)
     assert_almost_equal(model.theta, theta, decimal=2)
 
 
 def test_total_least_squares():
     x, y, theta = create_test_data()
-    model = PolynomialNarmax(
-        non_degree=2,
+    model = FROLS(
         n_terms=5,
         extended_least_squares=False,
         ylag=[1, 2],
         xlag=2,
         estimator="total_least_squares",
+        basis_function=Polynomial(degree=2),
     )
-    model.fit(x, y)
+    model.fit(X=x, y=y)
     print(model.theta)
     assert_almost_equal(model.theta, theta, decimal=2)
 
 
 def test_recursive_least_squares():
     x, y, theta = create_test_data()
-    model = PolynomialNarmax(
-        non_degree=2,
+    model = FROLS(
         n_terms=5,
         delta=0.00001,
         lam=0.99,
@@ -66,15 +67,15 @@ def test_recursive_least_squares():
         ylag=[1, 2],
         xlag=2,
         estimator="recursive_least_squares",
+        basis_function=Polynomial(degree=2),
     )
-    model.fit(x, y)
+    model.fit(X=x, y=y)
     assert_almost_equal(model.theta, theta, decimal=2)
 
 
 def test_affine_least_mean_squares():
     x, y, theta = create_test_data()
-    model = PolynomialNarmax(
-        non_degree=2,
+    model = FROLS(
         n_terms=5,
         mu=0.01,
         offset_covariance=0.2,
@@ -82,60 +83,60 @@ def test_affine_least_mean_squares():
         ylag=[1, 2],
         xlag=2,
         estimator="affine_least_mean_squares",
+        basis_function=Polynomial(degree=2),
     )
-    model.fit(x, y)
+    model.fit(X=x, y=y)
     assert_almost_equal(model.theta, theta, decimal=2)
 
 
 def test_least_mean_squares():
     x, y, theta = create_test_data()
-    model = PolynomialNarmax(
-        non_degree=2,
+    model = FROLS(
         n_terms=5,
         mu=0.1,
         extended_least_squares=False,
         ylag=[1, 2],
         xlag=2,
         estimator="least_mean_squares",
+        basis_function=Polynomial(degree=2),
     )
-    model.fit(x, y)
+    model.fit(X=x, y=y)
     assert_almost_equal(model.theta, theta, decimal=2)
 
 
 def test_least_mean_squares_sign_error():
     x, y, theta = create_test_data(n=5000)
-    model = PolynomialNarmax(
-        non_degree=2,
+    model = FROLS(
         n_terms=5,
         mu=0.01,
         extended_least_squares=False,
         ylag=[1, 2],
         xlag=2,
         estimator="least_mean_squares_sign_error",
+        basis_function=Polynomial(degree=2),
     )
-    model.fit(x, y)
+    model.fit(X=x, y=y)
     assert_almost_equal(model.theta, theta, decimal=2)
 
 
 def test_normalized_least_mean_squares():
     x, y, theta = create_test_data()
-    model = PolynomialNarmax(
-        non_degree=2,
+    model = FROLS(
         n_terms=5,
         mu=0.1,
         extended_least_squares=False,
         ylag=[1, 2],
         xlag=2,
         estimator="normalized_least_mean_squares",
+        basis_function=Polynomial(degree=2),
     )
-    model.fit(x, y)
+    model.fit(X=x, y=y)
     assert_almost_equal(model.theta, theta, decimal=2)
 
 
 def test_least_mean_squares_normalized_sign_error():
     x, y, theta = create_test_data()
-    model = PolynomialNarmax(
-        non_degree=2,
+    model = FROLS(
         n_terms=5,
         n_info_values=6,
         extended_least_squares=False,
@@ -144,60 +145,60 @@ def test_least_mean_squares_normalized_sign_error():
         info_criteria="aic",
         estimator="least_mean_squares_normalized_sign_error",
         mu=0.005,
+        basis_function=Polynomial(degree=2),
     )
-    model.fit(x, y)
+    model.fit(X=x, y=y)
     assert_almost_equal(model.theta, theta, decimal=2)
 
 
 def test_least_mean_squares_sign_regressor():
     x, y, theta = create_test_data()
-    model = PolynomialNarmax(
-        non_degree=2,
+    model = FROLS(
         n_terms=5,
         mu=0.1,
         extended_least_squares=False,
         ylag=[1, 2],
         xlag=2,
         estimator="least_mean_squares_sign_regressor",
+        basis_function=Polynomial(degree=2),
     )
-    model.fit(x, y)
+    model.fit(X=x, y=y)
     assert_almost_equal(model.theta, theta, decimal=2)
 
 
 def test_least_mean_squares_normalized_sign_regressor():
     x, y, theta = create_test_data()
-    model = PolynomialNarmax(
-        non_degree=2,
+    model = FROLS(
         n_terms=5,
         mu=0.1,
         extended_least_squares=False,
         ylag=[1, 2],
         xlag=2,
         estimator="least_mean_squares_normalized_sign_regressor",
+        basis_function=Polynomial(degree=2),
     )
-    model.fit(x, y)
+    model.fit(X=x, y=y)
     assert_almost_equal(model.theta, theta, decimal=2)
 
 
 def test_least_mean_squares_sign_sign():
     x, y, theta = create_test_data(n=5000)
-    model = PolynomialNarmax(
-        non_degree=2,
+    model = FROLS(
         n_terms=5,
         mu=0.001,
         extended_least_squares=False,
         ylag=[1, 2],
         xlag=2,
         estimator="least_mean_squares_sign_sign",
+        basis_function=Polynomial(degree=2),
     )
-    model.fit(x, y)
+    model.fit(X=x, y=y)
     assert_almost_equal(model.theta, theta, decimal=2)
 
 
 def test_least_mean_squares_normalized_sign_sign():
     x, y, theta = create_test_data(n=30000)
-    model = PolynomialNarmax(
-        non_degree=2,
+    model = FROLS(
         n_terms=5,
         mu=0.0001,
         # eps=0.05,
@@ -205,23 +206,24 @@ def test_least_mean_squares_normalized_sign_sign():
         ylag=[1, 2],
         xlag=2,
         estimator="least_mean_squares_normalized_sign_sign",
+        basis_function=Polynomial(degree=2),
     )
-    model.fit(x, y)
+    model.fit(X=x, y=y)
     assert_almost_equal(model.theta, theta, decimal=2)
 
 
 def test_least_mean_squares_mixed_norm():
     x, y, theta = create_test_data(n=30000)
-    model = PolynomialNarmax(
-        non_degree=2,
+    model = FROLS(
         n_terms=5,
         mu=0.05,
         extended_least_squares=False,
         ylag=[1, 2],
         xlag=2,
         estimator="least_mean_squares_mixed_norm",
+        basis_function=Polynomial(degree=2),
     )
-    model.fit(x, y)
+    model.fit(X=x, y=y)
     assert_almost_equal(model.theta, theta, decimal=2)
 
 
