@@ -5,13 +5,16 @@
 # License: BSD 3 clause
 
 import numpy as np
-from ..utils._check_arrays import check_X_y, _num_features, _check_positive_int
-from ..narmax_base import GenerateRegressors, ModelPrediction
-from ..narmax_base import HouseHolder
-from ..narmax_base import InformationMatrix
-from ..narmax_base import ModelInformation
-from ..narmax_base import ModelPrediction
+
+from ..narmax_base import (
+    GenerateRegressors,
+    HouseHolder,
+    InformationMatrix,
+    ModelInformation,
+    ModelPrediction,
+)
 from ..parameter_estimation.estimators import Estimators
+from ..utils._check_arrays import _check_positive_int, _num_features
 
 
 class SimulateNARMAX(
@@ -28,7 +31,7 @@ class SimulateNARMAX(
 
     .. math::
 
-        y_k= F^\ell[y_{k-1}, \dotsc, y_{k-n_y},x_{k-d}, x_{k-d-1}, \dotsc, x_{k-d-n_x} + e_{k-1}, \dotsc, e_{k-n_e}] + e_k
+        y_k= F^\ell[y_{k-1}, \dotsc, y_{k-n_y},x_{k-d}, x_{k-d-1}, \dotsc, x_{k-d-n_x}, e_{k-1}, \dotsc, e_{k-n_e}] + e_k
 
     where :math:`n_y\in \mathbb{N}^*`, :math:`n_x \in \mathbb{N}`, :math:`n_e \in \mathbb{N}`,
     are the maximum lags for the system output and input respectively;
@@ -117,6 +120,7 @@ class SimulateNARMAX(
         self,
         *,
         estimator="recursive_least_squares",
+        elag=2,
         extended_least_squares=False,
         lam=0.98,
         delta=0.01,
@@ -140,6 +144,7 @@ class SimulateNARMAX(
             gama=gama,
             weight=weight,
         )
+        self.elag = elag
         self.model_type = model_type
         self.basis_function = basis_function
         self.estimator = estimator
@@ -197,8 +202,7 @@ class SimulateNARMAX(
             The forecast horizon.
         theta : array-like of shape = number_of_model_elements
             The parameters of the model.
-        plot : bool, default=True
-            Indicate if the user wants to plot or not.
+
         Returns
         -------
         yhat : ndarray of floats
@@ -237,10 +241,6 @@ class SimulateNARMAX(
                 raise TypeError(
                     f"If estimate_parameter is True, X_train and y_train must be an np.ndarray. Got {type(y_train)}"
                 )
-            if y_train is None:
-                raise ValueError("y_train cannot be None")
-
-        # self._n_inputs = _num_features(X_test) ####
 
         if X_test is not None:
             self._n_inputs = _num_features(X_test)
@@ -280,10 +280,7 @@ class SimulateNARMAX(
             elif self.model_type == "NFIR":
                 lagged_data = self.build_input_matrix(X_train, self.xlag)
                 self.max_lag = self._get_max_lag(xlag=self.xlag)
-            else:
-                raise ValueError(
-                    "Unrecognized model type. The model_type should be NARMAX, NAR or NFIR."
-                )
+
             psi = self.basis_function.fit(
                 lagged_data, self.max_lag, predefined_regressors=self.pivv
             )
@@ -310,10 +307,7 @@ class SimulateNARMAX(
             elif self.model_type == "NFIR":
                 lagged_data = self.build_input_matrix(X_train, self.xlag)
                 self.max_lag = self._get_max_lag(xlag=self.xlag)
-            else:
-                raise ValueError(
-                    "Unrecognized model type. The model_type should be NARMAX, NAR or NFIR."
-                )
+
             psi = self.basis_function.fit(
                 lagged_data, self.max_lag, predefined_regressors=self.pivv
             )
@@ -327,9 +321,6 @@ class SimulateNARMAX(
                     psi, y_train, self.theta, self.non_degree, self.elag, self.max_lag
                 )
 
-        # yhat = self.predict(X_test, y_test, steps_ahead)
-        # return yhat
-
         if self.basis_function.__class__.__name__ == "Polynomial":
             if steps_ahead is None:
                 return self._model_prediction(
