@@ -2,12 +2,12 @@
 #           Wilson Rocha Lacerda Junior <wilsonrljr@outlook.com>
 # License: BSD 3 clause
 
-import warnings
 import functools
+import warnings
 
 
 def deprecated(version, future_version=None, message=None, alternative=None, **kwargs):
-    """This docorater is adapted from astroML decorator:
+    """This decorator is adapted from astroML decorator:
     https://github.com/astroML/astroML/blob/f66558232f6d33cb34ecd1bed8a80b9db7ae1c30/astroML/utils/decorators.py#L120
     """
 
